This is a plugin for simpleSAMLphp.

It enables simpleSAMLphp to do two factor authentication against 
privacyIDEA. Users can authenticate with normal OTP tokens, 
Challenge Response tokens like EMail and SMS or with U2F devices.
TiQR is currently not supported.

The package is listed at packagist.
https://packagist.org/packages/privacyidea/simplesamlphp-module-privacyidea

You can install this plugin into simpleSAMLphp like this:

    php composer.phar require privacyidea/simplesamlphp-module-privacyidea:v1.5
